@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2020 Red Hat, Inc.
+# Copyright (C) 2022 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -94,7 +94,7 @@ designed to be *fast* to validate. This is the opposite of what we desire for pa
 storage. In the unlikely event of a disclosure, you want hashes to be *difficult* to
 verify, as this adds a cost of work to an attacker.
 
-In Directory Server, we offer one hash suitable for this (PBKDF2_SHA256) and one hash
+In Directory Server, we offer one hash suitable for this (PBKDF2-SHA512) and one hash
 for "legacy" support (SSHA512).
 
 Your configuration does not use these for password storage or the root password storage
@@ -110,7 +110,7 @@ is started, they will use the server provided defaults that are secure.
 
 You can also use 'dsconf' to replace these values.  Here is an example:
 
-    # dsconf slapd-YOUR_INSTANCE config replace passwordStorageScheme=PBKDF2_SHA256 nsslapd-rootpwstoragescheme=PBKDF2_SHA256"""
+    # dsconf slapd-YOUR_INSTANCE config replace passwordStorageScheme=PBKDF2-SHA512 nsslapd-rootpwstoragescheme=PBKDF2-SHA512"""
 }
 
 # Security checks
@@ -152,11 +152,11 @@ the entry - ie these are synchronous.
 
 However, when this is > 0, these are performed asynchronously.
 
-This leads to only having referint enabled on one master in MMR to prevent replication conflicts and loops.
+This leads to only having referint enabled on one supplier in MMR to prevent replication conflicts and loops.
 Additionally, because these are performed in the background these updates may cause spurious update
 delays to your server by batching changes rather than smaller updates during sync processing.
 
-We advise that you set this value to 0, and enable referint on all masters as it provides a more predictable behaviour.
+We advise that you set this value to 0, and enable referint on all suppliers as it provides a more predictable behaviour.
 """,
     'fix': """Set referint-update-delay to 0.
 
@@ -182,7 +182,26 @@ an index defined that has at least the equality "eq" index type.  You will
 need to reindex the database after adding the missing index type. Here is an
 example using dsconf:
 
-    # dsconf slapd-YOUR_INSTANCE backend index --attr=ATTR --reindex --index-type=eq BACKEND
+    # dsconf slapd-YOUR_INSTANCE backend index add --attr=ATTR --reindex --index-type=eq BACKEND
+"""
+}
+
+# MemberOf plugin checks
+DSMOLE0001 = {
+    'dsle': 'DSMOLE0001',
+    'severity': 'HIGH',
+    'description': 'MemberOf operations can become very slow',
+    'items': ['cn=memberof plugin,cn=plugins,cn=config', ],
+    'detail': """The MemberOf plugin does internal searches when updating a group, or running the fixup task.
+These internal searches will be unindexed leading to poor performance and high CPU.
+
+We advise that you index the memberOf group attributes for equality searches.
+""",
+    'fix': """Check the attributes set in "memberofgroupattr" to make sure they have
+an index defined that has equality "eq" index type.  You will need to reindex the
+database after adding the missing index type. Here is an example using dsconf:
+
+    # dsconf slapd-YOUR_INSTANCE backend index add --attr=ATTR --index-type=eq --reindex BACKEND
 """
 }
 
@@ -296,13 +315,13 @@ DSCLLE0001 = {
     'dsle': 'DSCLLE0001',
     'severity': 'LOW',
     'description': 'Changelog trimming not configured.',
-    'items': ['Replication', 'Changelog'],
+    'items': ['Replication', 'Changelog',  'Backends'],
     'detail': """The replication changelog does have any kind of trimming configured.  This will
 lead to the changelog size growing indefinitely.""",
     'fix': """Configure changelog trimming, preferably by setting the maximum age of a changelog
 record.  Here is an example:
 
-    # dsconf slapd-YOUR_INSTANCE replication set-changelog --max-age 30d"""
+    # dsconf slapd-YOUR_INSTANCE replication set-changelog --suffix YOUR_SUFFIX --max-age 30d"""
 }
 
 # Certificate checks
